# coding: utf-8

"""
    smritea SDK API

    Public SDK API for smritea AI memory system — programmatic memory operations via API key

    The version of the OpenAPI document: 1.0.0
    Contact: support@smritea.ai
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import json
from enum import Enum
from typing_extensions import Self


class ModelEnumsSearchMethod(str, Enum):
    """
    ModelEnumsSearchMethod
    """

    """
    allowed enum values
    """
    SearchMethodInvalid = 'invalid_search_method'
    SearchMethodQuickSearch = 'quick_search'
    SearchMethodDeepSearch = 'deep_search'
    SearchMethodContextAwareSearch = 'context_aware_search'
    SearchMethodGraphProximity = 'graph_proximity'
    SearchMethodDiversified = 'diversified'
    SearchMethodSemanticRerank = 'semantic_rerank'

    @classmethod
    def from_json(cls, json_str: str) -> Self:
        """Create an instance of ModelEnumsSearchMethod from a JSON string"""
        return cls(json.loads(json_str))


