# coding: utf-8

# flake8: noqa

"""
    smritea SDK API

    Public SDK API for smritea AI memory system — programmatic memory operations via API key

    The version of the OpenAPI document: 1.0.0
    Contact: support@smritea.ai
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "SDKMemoryApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "CommondtoAPIError",
    "CommondtoEntityExtractionConfig",
    "CommondtoFactExtractionConfig",
    "CommondtoPersonaDomainConfig",
    "CommondtoPersonaExtractionConfig",
    "CommondtoRelativeStandingConfig",
    "MemoryCreateMemoryRequest",
    "MemoryMemoryResponse",
    "MemorySearchMemoriesResponse",
    "MemorySearchMemoryRequest",
    "MemorySearchMemoryResponse",
    "ModelEnumsSearchMethod",
]

# import apis into sdk package
from smritea._internal.autogen.smritea_cloud_sdk.api.sdk_memory_api import SDKMemoryApi as SDKMemoryApi

# import ApiClient
from smritea._internal.autogen.smritea_cloud_sdk.api_response import ApiResponse as ApiResponse
from smritea._internal.autogen.smritea_cloud_sdk.api_client import ApiClient as ApiClient
from smritea._internal.autogen.smritea_cloud_sdk.configuration import Configuration as Configuration
from smritea._internal.autogen.smritea_cloud_sdk.exceptions import OpenApiException as OpenApiException
from smritea._internal.autogen.smritea_cloud_sdk.exceptions import ApiTypeError as ApiTypeError
from smritea._internal.autogen.smritea_cloud_sdk.exceptions import ApiValueError as ApiValueError
from smritea._internal.autogen.smritea_cloud_sdk.exceptions import ApiKeyError as ApiKeyError
from smritea._internal.autogen.smritea_cloud_sdk.exceptions import ApiAttributeError as ApiAttributeError
from smritea._internal.autogen.smritea_cloud_sdk.exceptions import ApiException as ApiException

# import models into sdk package
from smritea._internal.autogen.smritea_cloud_sdk.models.commondto_api_error import CommondtoAPIError as CommondtoAPIError
from smritea._internal.autogen.smritea_cloud_sdk.models.commondto_entity_extraction_config import CommondtoEntityExtractionConfig as CommondtoEntityExtractionConfig
from smritea._internal.autogen.smritea_cloud_sdk.models.commondto_fact_extraction_config import CommondtoFactExtractionConfig as CommondtoFactExtractionConfig
from smritea._internal.autogen.smritea_cloud_sdk.models.commondto_persona_domain_config import CommondtoPersonaDomainConfig as CommondtoPersonaDomainConfig
from smritea._internal.autogen.smritea_cloud_sdk.models.commondto_persona_extraction_config import CommondtoPersonaExtractionConfig as CommondtoPersonaExtractionConfig
from smritea._internal.autogen.smritea_cloud_sdk.models.commondto_relative_standing_config import CommondtoRelativeStandingConfig as CommondtoRelativeStandingConfig
from smritea._internal.autogen.smritea_cloud_sdk.models.memory_create_memory_request import MemoryCreateMemoryRequest as MemoryCreateMemoryRequest
from smritea._internal.autogen.smritea_cloud_sdk.models.memory_memory_response import MemoryMemoryResponse as MemoryMemoryResponse
from smritea._internal.autogen.smritea_cloud_sdk.models.memory_search_memories_response import MemorySearchMemoriesResponse as MemorySearchMemoriesResponse
from smritea._internal.autogen.smritea_cloud_sdk.models.memory_search_memory_request import MemorySearchMemoryRequest as MemorySearchMemoryRequest
from smritea._internal.autogen.smritea_cloud_sdk.models.memory_search_memory_response import MemorySearchMemoryResponse as MemorySearchMemoryResponse
from smritea._internal.autogen.smritea_cloud_sdk.models.model_enums_search_method import ModelEnumsSearchMethod as ModelEnumsSearchMethod

